@@ -8,7 +8,11 @@
 #include "camera.h"
 
 extern "C" {
-#include <libimagevisualresult/visualresult.h>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #include <libimagevisualresult6/visualresult.h>
+#else
+    #include <libimagevisualresult/visualresult.h>
+#endif
 }
 
 #include <QFile>
